Index: cc/input/input_handler.h |
diff --git a/cc/input/input_handler.h b/cc/input/input_handler.h |
index 9b96db789d1d03c4a5fc6fc655288ffb3ad0f0d1..9d0ce6795b4c4e790a57ea87069ea72bfa74d79e 100644 |
--- a/cc/input/input_handler.h |
+++ b/cc/input/input_handler.h |
@@ -105,6 +105,12 @@ class CC_EXPORT InputHandler { |
NON_BUBBLING_GESTURE |
}; |
+ enum TouchEventDisposition { |
bokan
2016/11/17 15:39:28
This looks unused?
lanwei
2016/11/18 00:54:07
Acknowledged.
|
+ HANDLE, |
+ NOT_HANDLE, |
+ NOT_HANDLE_NON_BLOCKING_DUE_TO_FLING |
+ }; |
+ |
// Binds a client to this handler to receive notifications. Only one client |
// can be bound to an InputHandler. The client must live at least until the |
// handler calls WillShutdown() on the client. |
@@ -188,9 +194,12 @@ class CC_EXPORT InputHandler { |
virtual EventListenerProperties GetEventListenerProperties( |
EventListenerClass event_class) const = 0; |
- // Whether the page should be given the opportunity to suppress scrolling by |
- // consuming touch events that started at |viewport_point|. |
- virtual bool DoTouchEventsBlockScrollAt(const gfx::Point& viewport_point) = 0; |
+ // It returns the type of event listener at the given viewport point. Such as |
+ // if the page has a touch handler or not, and whether the page should |
+ // suppress scrolling by consuming touch events that started at |
+ // |viewport_point|. |
+ virtual EventListenerProperties EventListenerTypeForTouchStartAt( |
+ const gfx::Point& viewport_point) = 0; |
// Calling CreateLatencyInfoSwapPromiseMonitor() to get a scoped |
// LatencyInfoSwapPromiseMonitor. During the life time of the |